@@ -9,9 +9,15 @@
 #include <cmath>
 #include <dirent.h>
 
+#include <glib.h>
+#include <dbus/dbus-glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
+
+
 #define INTERVAL_IDLE 1000000
 #define INTERVAL_ACTIVE 100000
 
+		
 class Client
 {
 	public:
@@ -36,15 +42,23 @@ class ProximityDaemon
 		char currentState;
 		FILE* fp;
 
-		void readProx(); //looped reading
+		static ProximityDaemon* me;
+		static DBusHandlerResult methodFilter (DBusConnection *connection, DBusMessage *message, void *user_data);
+		DBusHandlerResult methodFilterD (DBusConnection *connection, DBusMessage *message, void *user_data);
+		
+		void readProxD(); //looped reading
 		void readSensor(); //single read
 
+		static void* readProx(void* object);
+		
 		const char* file;
 
 		void emitState(char newState_);
 
 		void connectToDbusSignal();
 
+		pthread_t proxThread;
+		
 		DBusMessage* msgSig;
 		DBusMessageIter argsSig;
 		DBusConnection* connSig;
@@ -52,7 +66,7 @@ class ProximityDaemon
 		int retSig;
 		dbus_uint32_t serialSig;
 	
-		void handleMethodCall();
+		void handleMethodCall(DBusMessage* msgMth_);
 		void listen();
 		void turnOff();
 		void turnOn();
@@ -68,7 +82,8 @@ class ProximityDaemon
 		int paramMthPid;
 		int intervalMth;
 		int connectedMth;
-				  
+		GMainLoop *loop;	
+		
 		void changeInterval(int mInterval_, int pid_);
 		
 		std::vector<Client*> pids;
